BetfairDataConfigBuilder

Struct BetfairDataConfigBuilder 

pub struct BetfairDataConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BetfairDataConfigBuilder<S>

pub fn build(self) -> BetfairDataConfig
where S: IsComplete,

Finish building and return the requested object

pub fn account_currency( self, value: String, ) -> BetfairDataConfigBuilder<SetAccountCurrency<S>>
where S::AccountCurrency: IsUnset,

Optional (Some / Option setters). Default: "GBP".to_string().

Account currency code.

pub fn maybe_account_currency( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetAccountCurrency<S>>
where S::AccountCurrency: IsUnset,

Optional (Some / Option setters). Default: "GBP".to_string().

Account currency code.

pub fn username(self, value: String) -> BetfairDataConfigBuilder<SetUsername<S>>
where S::Username: IsUnset,

Optional (Some / Option setters). Optional Betfair username.

pub fn maybe_username( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetUsername<S>>
where S::Username: IsUnset,

Optional (Some / Option setters). Optional Betfair username.

pub fn password(self, value: String) -> BetfairDataConfigBuilder<SetPassword<S>>
where S::Password: IsUnset,

Optional (Some / Option setters). Optional Betfair password.

pub fn maybe_password( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetPassword<S>>
where S::Password: IsUnset,

Optional (Some / Option setters). Optional Betfair password.

pub fn app_key(self, value: String) -> BetfairDataConfigBuilder<SetAppKey<S>>
where S::AppKey: IsUnset,

Optional (Some / Option setters). Optional Betfair application key.

pub fn maybe_app_key( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetAppKey<S>>
where S::AppKey: IsUnset,

Optional (Some / Option setters). Optional Betfair application key.

pub fn proxy_url( self, value: String, ) -> BetfairDataConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP requests.

pub fn maybe_proxy_url( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP requests.

pub fn request_rate_per_second( self, value: u32, ) -> BetfairDataConfigBuilder<SetRequestRatePerSecond<S>>
where S::RequestRatePerSecond: IsUnset,

Optional (Some / Option setters). Default: 5.

General HTTP request rate limit per second.

pub fn maybe_request_rate_per_second( self, value: Option<u32>, ) -> BetfairDataConfigBuilder<SetRequestRatePerSecond<S>>
where S::RequestRatePerSecond: IsUnset,

Optional (Some / Option setters). Default: 5.

General HTTP request rate limit per second.

pub fn default_min_notional( self, value: f64, ) -> BetfairDataConfigBuilder<SetDefaultMinNotional<S>>
where S::DefaultMinNotional: IsUnset,

Optional (Some / Option setters). Optional default minimum notional in account_currency.

pub fn maybe_default_min_notional( self, value: Option<f64>, ) -> BetfairDataConfigBuilder<SetDefaultMinNotional<S>>
where S::DefaultMinNotional: IsUnset,

Optional (Some / Option setters). Optional default minimum notional in account_currency.

pub fn event_type_ids( self, value: Vec<String>, ) -> BetfairDataConfigBuilder<SetEventTypeIds<S>>
where S::EventTypeIds: IsUnset,

Optional (Some / Option setters). Optional event type ID filter.

pub fn maybe_event_type_ids( self, value: Option<Vec<String>>, ) -> BetfairDataConfigBuilder<SetEventTypeIds<S>>
where S::EventTypeIds: IsUnset,

Optional (Some / Option setters). Optional event type ID filter.

pub fn event_type_names( self, value: Vec<String>, ) -> BetfairDataConfigBuilder<SetEventTypeNames<S>>
where S::EventTypeNames: IsUnset,

Optional (Some / Option setters). Optional event type name filter.

pub fn maybe_event_type_names( self, value: Option<Vec<String>>, ) -> BetfairDataConfigBuilder<SetEventTypeNames<S>>
where S::EventTypeNames: IsUnset,

Optional (Some / Option setters). Optional event type name filter.

pub fn event_ids( self, value: Vec<String>, ) -> BetfairDataConfigBuilder<SetEventIds<S>>
where S::EventIds: IsUnset,

Optional (Some / Option setters). Optional event ID filter.

pub fn maybe_event_ids( self, value: Option<Vec<String>>, ) -> BetfairDataConfigBuilder<SetEventIds<S>>
where S::EventIds: IsUnset,

Optional (Some / Option setters). Optional event ID filter.

pub fn country_codes( self, value: Vec<String>, ) -> BetfairDataConfigBuilder<SetCountryCodes<S>>
where S::CountryCodes: IsUnset,

Optional (Some / Option setters). Optional country code filter.

pub fn maybe_country_codes( self, value: Option<Vec<String>>, ) -> BetfairDataConfigBuilder<SetCountryCodes<S>>
where S::CountryCodes: IsUnset,

Optional (Some / Option setters). Optional country code filter.

pub fn market_types( self, value: Vec<String>, ) -> BetfairDataConfigBuilder<SetMarketTypes<S>>
where S::MarketTypes: IsUnset,

Optional (Some / Option setters). Optional market type filter.

pub fn maybe_market_types( self, value: Option<Vec<String>>, ) -> BetfairDataConfigBuilder<SetMarketTypes<S>>
where S::MarketTypes: IsUnset,

Optional (Some / Option setters). Optional market type filter.

pub fn market_ids( self, value: Vec<String>, ) -> BetfairDataConfigBuilder<SetMarketIds<S>>
where S::MarketIds: IsUnset,

Optional (Some / Option setters). Optional market ID filter.

pub fn maybe_market_ids( self, value: Option<Vec<String>>, ) -> BetfairDataConfigBuilder<SetMarketIds<S>>
where S::MarketIds: IsUnset,

Optional (Some / Option setters). Optional market ID filter.

pub fn min_market_start_time( self, value: String, ) -> BetfairDataConfigBuilder<SetMinMarketStartTime<S>>
where S::MinMarketStartTime: IsUnset,

Optional (Some / Option setters). Optional lower bound for market start time.

pub fn maybe_min_market_start_time( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetMinMarketStartTime<S>>
where S::MinMarketStartTime: IsUnset,

Optional (Some / Option setters). Optional lower bound for market start time.

pub fn max_market_start_time( self, value: String, ) -> BetfairDataConfigBuilder<SetMaxMarketStartTime<S>>
where S::MaxMarketStartTime: IsUnset,

Optional (Some / Option setters). Optional upper bound for market start time.

pub fn maybe_max_market_start_time( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetMaxMarketStartTime<S>>
where S::MaxMarketStartTime: IsUnset,

Optional (Some / Option setters). Optional upper bound for market start time.

pub fn stream_host( self, value: String, ) -> BetfairDataConfigBuilder<SetStreamHost<S>>
where S::StreamHost: IsUnset,

Optional (Some / Option setters). Optional override for stream host.

pub fn maybe_stream_host( self, value: Option<String>, ) -> BetfairDataConfigBuilder<SetStreamHost<S>>
where S::StreamHost: IsUnset,

Optional (Some / Option setters). Optional override for stream host.

pub fn stream_port( self, value: u16, ) -> BetfairDataConfigBuilder<SetStreamPort<S>>
where S::StreamPort: IsUnset,

Optional (Some / Option setters). Optional override for stream port.

pub fn maybe_stream_port( self, value: Option<u16>, ) -> BetfairDataConfigBuilder<SetStreamPort<S>>
where S::StreamPort: IsUnset,

Optional (Some / Option setters). Optional override for stream port.

pub fn stream_heartbeat_ms( self, value: u64, ) -> BetfairDataConfigBuilder<SetStreamHeartbeatMs<S>>
where S::StreamHeartbeatMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Interval between stream heartbeat messages in milliseconds.

pub fn maybe_stream_heartbeat_ms( self, value: Option<u64>, ) -> BetfairDataConfigBuilder<SetStreamHeartbeatMs<S>>
where S::StreamHeartbeatMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Interval between stream heartbeat messages in milliseconds.

pub fn stream_idle_timeout_ms( self, value: u64, ) -> BetfairDataConfigBuilder<SetStreamIdleTimeoutMs<S>>
where S::StreamIdleTimeoutMs: IsUnset,

Optional (Some / Option setters). Default: 60_000.

Stream idle timeout in milliseconds.

pub fn maybe_stream_idle_timeout_ms( self, value: Option<u64>, ) -> BetfairDataConfigBuilder<SetStreamIdleTimeoutMs<S>>
where S::StreamIdleTimeoutMs: IsUnset,

Optional (Some / Option setters). Default: 60_000.

Stream idle timeout in milliseconds.

pub fn stream_reconnect_delay_initial_ms( self, value: u64, ) -> BetfairDataConfigBuilder<SetStreamReconnectDelayInitialMs<S>>
where S::StreamReconnectDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 2_000.

Initial reconnection backoff in milliseconds.

pub fn maybe_stream_reconnect_delay_initial_ms( self, value: Option<u64>, ) -> BetfairDataConfigBuilder<SetStreamReconnectDelayInitialMs<S>>
where S::StreamReconnectDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 2_000.

Initial reconnection backoff in milliseconds.

pub fn stream_reconnect_delay_max_ms( self, value: u64, ) -> BetfairDataConfigBuilder<SetStreamReconnectDelayMaxMs<S>>
where S::StreamReconnectDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 30_000.

Maximum reconnection backoff in milliseconds.

pub fn maybe_stream_reconnect_delay_max_ms( self, value: Option<u64>, ) -> BetfairDataConfigBuilder<SetStreamReconnectDelayMaxMs<S>>
where S::StreamReconnectDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 30_000.

Maximum reconnection backoff in milliseconds.

pub fn stream_use_tls( self, value: bool, ) -> BetfairDataConfigBuilder<SetStreamUseTls<S>>
where S::StreamUseTls: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use TLS for the stream connection.

pub fn maybe_stream_use_tls( self, value: Option<bool>, ) -> BetfairDataConfigBuilder<SetStreamUseTls<S>>
where S::StreamUseTls: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use TLS for the stream connection.

pub fn stream_conflate_ms( self, value: u64, ) -> BetfairDataConfigBuilder<SetStreamConflateMs<S>>
where S::StreamConflateMs: IsUnset,

Optional (Some / Option setters). Stream conflation setting in milliseconds. When set, Betfair batches stream updates for this interval. None uses Betfair defaults.

pub fn maybe_stream_conflate_ms( self, value: Option<u64>, ) -> BetfairDataConfigBuilder<SetStreamConflateMs<S>>
where S::StreamConflateMs: IsUnset,

Optional (Some / Option setters). Stream conflation setting in milliseconds. When set, Betfair batches stream updates for this interval. None uses Betfair defaults.

pub fn subscription_delay_secs( self, value: u64, ) -> BetfairDataConfigBuilder<SetSubscriptionDelaySecs<S>>
where S::SubscriptionDelaySecs: IsUnset,

Optional (Some / Option setters). Default: 3.

Delay in seconds before sending the initial subscription message after connecting.

pub fn maybe_subscription_delay_secs( self, value: Option<u64>, ) -> BetfairDataConfigBuilder<SetSubscriptionDelaySecs<S>>
where S::SubscriptionDelaySecs: IsUnset,

Optional (Some / Option setters). Default: 3.

Delay in seconds before sending the initial subscription message after connecting.

pub fn subscribe_race_data( self, value: bool, ) -> BetfairDataConfigBuilder<SetSubscribeRaceData<S>>
where S::SubscribeRaceData: IsUnset,

Optional (Some / Option setters). Default: false.

Subscribe to the race stream for Total Performance Data (TPD).

pub fn maybe_subscribe_race_data( self, value: Option<bool>, ) -> BetfairDataConfigBuilder<SetSubscribeRaceData<S>>
where S::SubscribeRaceData: IsUnset,

Optional (Some / Option setters). Default: false.

Subscribe to the race stream for Total Performance Data (TPD).