BetfairExecConfigBuilder

Struct BetfairExecConfigBuilder 

pub struct BetfairExecConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BetfairExecConfigBuilder<S>

pub fn build(self) -> BetfairExecConfig
where S: IsComplete,

Finish building and return the requested object

pub fn trader_id( self, value: TraderId, ) -> BetfairExecConfigBuilder<SetTraderId<S>>
where S::TraderId: IsUnset,

Optional (Some / Option setters). Default: TraderId::from("TRADER-001").

Trader ID for the client core.

pub fn maybe_trader_id( self, value: Option<TraderId>, ) -> BetfairExecConfigBuilder<SetTraderId<S>>
where S::TraderId: IsUnset,

Optional (Some / Option setters). Default: TraderId::from("TRADER-001").

Trader ID for the client core.

pub fn account_id( self, value: AccountId, ) -> BetfairExecConfigBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). Default: AccountId::from("BETFAIR-001").

Account ID for the client core.

pub fn maybe_account_id( self, value: Option<AccountId>, ) -> BetfairExecConfigBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). Default: AccountId::from("BETFAIR-001").

Account ID for the client core.

pub fn account_currency( self, value: String, ) -> BetfairExecConfigBuilder<SetAccountCurrency<S>>
where S::AccountCurrency: IsUnset,

Optional (Some / Option setters). Default: "GBP".to_string().

Account currency code.

pub fn maybe_account_currency( self, value: Option<String>, ) -> BetfairExecConfigBuilder<SetAccountCurrency<S>>
where S::AccountCurrency: IsUnset,

Optional (Some / Option setters). Default: "GBP".to_string().

Account currency code.

pub fn username(self, value: String) -> BetfairExecConfigBuilder<SetUsername<S>>
where S::Username: IsUnset,

Optional (Some / Option setters). Optional Betfair username.

pub fn maybe_username( self, value: Option<String>, ) -> BetfairExecConfigBuilder<SetUsername<S>>
where S::Username: IsUnset,

Optional (Some / Option setters). Optional Betfair username.

pub fn password(self, value: String) -> BetfairExecConfigBuilder<SetPassword<S>>
where S::Password: IsUnset,

Optional (Some / Option setters). Optional Betfair password.

pub fn maybe_password( self, value: Option<String>, ) -> BetfairExecConfigBuilder<SetPassword<S>>
where S::Password: IsUnset,

Optional (Some / Option setters). Optional Betfair password.

pub fn app_key(self, value: String) -> BetfairExecConfigBuilder<SetAppKey<S>>
where S::AppKey: IsUnset,

Optional (Some / Option setters). Optional Betfair application key.

pub fn maybe_app_key( self, value: Option<String>, ) -> BetfairExecConfigBuilder<SetAppKey<S>>
where S::AppKey: IsUnset,

Optional (Some / Option setters). Optional Betfair application key.

pub fn proxy_url( self, value: String, ) -> BetfairExecConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP requests.

pub fn maybe_proxy_url( self, value: Option<String>, ) -> BetfairExecConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP requests.

pub fn request_rate_per_second( self, value: u32, ) -> BetfairExecConfigBuilder<SetRequestRatePerSecond<S>>
where S::RequestRatePerSecond: IsUnset,

Optional (Some / Option setters). Default: 5.

General HTTP request rate limit per second.

pub fn maybe_request_rate_per_second( self, value: Option<u32>, ) -> BetfairExecConfigBuilder<SetRequestRatePerSecond<S>>
where S::RequestRatePerSecond: IsUnset,

Optional (Some / Option setters). Default: 5.

General HTTP request rate limit per second.

pub fn order_request_rate_per_second( self, value: u32, ) -> BetfairExecConfigBuilder<SetOrderRequestRatePerSecond<S>>
where S::OrderRequestRatePerSecond: IsUnset,

Optional (Some / Option setters). Default: 20.

Order HTTP request rate limit per second.

pub fn maybe_order_request_rate_per_second( self, value: Option<u32>, ) -> BetfairExecConfigBuilder<SetOrderRequestRatePerSecond<S>>
where S::OrderRequestRatePerSecond: IsUnset,

Optional (Some / Option setters). Default: 20.

Order HTTP request rate limit per second.

pub fn stream_host( self, value: String, ) -> BetfairExecConfigBuilder<SetStreamHost<S>>
where S::StreamHost: IsUnset,

Optional (Some / Option setters). Optional override for stream host.

pub fn maybe_stream_host( self, value: Option<String>, ) -> BetfairExecConfigBuilder<SetStreamHost<S>>
where S::StreamHost: IsUnset,

Optional (Some / Option setters). Optional override for stream host.

pub fn stream_port( self, value: u16, ) -> BetfairExecConfigBuilder<SetStreamPort<S>>
where S::StreamPort: IsUnset,

Optional (Some / Option setters). Optional override for stream port.

pub fn maybe_stream_port( self, value: Option<u16>, ) -> BetfairExecConfigBuilder<SetStreamPort<S>>
where S::StreamPort: IsUnset,

Optional (Some / Option setters). Optional override for stream port.

pub fn stream_heartbeat_ms( self, value: u64, ) -> BetfairExecConfigBuilder<SetStreamHeartbeatMs<S>>
where S::StreamHeartbeatMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Interval between stream heartbeat messages in milliseconds.

pub fn maybe_stream_heartbeat_ms( self, value: Option<u64>, ) -> BetfairExecConfigBuilder<SetStreamHeartbeatMs<S>>
where S::StreamHeartbeatMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Interval between stream heartbeat messages in milliseconds.

pub fn stream_idle_timeout_ms( self, value: u64, ) -> BetfairExecConfigBuilder<SetStreamIdleTimeoutMs<S>>
where S::StreamIdleTimeoutMs: IsUnset,

Optional (Some / Option setters). Default: 60_000.

Stream idle timeout in milliseconds.

pub fn maybe_stream_idle_timeout_ms( self, value: Option<u64>, ) -> BetfairExecConfigBuilder<SetStreamIdleTimeoutMs<S>>
where S::StreamIdleTimeoutMs: IsUnset,

Optional (Some / Option setters). Default: 60_000.

Stream idle timeout in milliseconds.

pub fn stream_reconnect_delay_initial_ms( self, value: u64, ) -> BetfairExecConfigBuilder<SetStreamReconnectDelayInitialMs<S>>
where S::StreamReconnectDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 2_000.

Initial reconnection backoff in milliseconds.

pub fn maybe_stream_reconnect_delay_initial_ms( self, value: Option<u64>, ) -> BetfairExecConfigBuilder<SetStreamReconnectDelayInitialMs<S>>
where S::StreamReconnectDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 2_000.

Initial reconnection backoff in milliseconds.

pub fn stream_reconnect_delay_max_ms( self, value: u64, ) -> BetfairExecConfigBuilder<SetStreamReconnectDelayMaxMs<S>>
where S::StreamReconnectDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 30_000.

Maximum reconnection backoff in milliseconds.

pub fn maybe_stream_reconnect_delay_max_ms( self, value: Option<u64>, ) -> BetfairExecConfigBuilder<SetStreamReconnectDelayMaxMs<S>>
where S::StreamReconnectDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 30_000.

Maximum reconnection backoff in milliseconds.

pub fn stream_use_tls( self, value: bool, ) -> BetfairExecConfigBuilder<SetStreamUseTls<S>>
where S::StreamUseTls: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use TLS for the stream connection.

pub fn maybe_stream_use_tls( self, value: Option<bool>, ) -> BetfairExecConfigBuilder<SetStreamUseTls<S>>
where S::StreamUseTls: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use TLS for the stream connection.

pub fn stream_market_ids_filter( self, value: Vec<String>, ) -> BetfairExecConfigBuilder<SetStreamMarketIdsFilter<S>>
where S::StreamMarketIdsFilter: IsUnset,

Optional (Some / Option setters). Market IDs to filter on the order stream. When set, OCM updates for markets not in this list are skipped. None processes all markets.

pub fn maybe_stream_market_ids_filter( self, value: Option<Vec<String>>, ) -> BetfairExecConfigBuilder<SetStreamMarketIdsFilter<S>>
where S::StreamMarketIdsFilter: IsUnset,

Optional (Some / Option setters). Market IDs to filter on the order stream. When set, OCM updates for markets not in this list are skipped. None processes all markets.

pub fn ignore_external_orders( self, value: bool, ) -> BetfairExecConfigBuilder<SetIgnoreExternalOrders<S>>
where S::IgnoreExternalOrders: IsUnset,

Optional (Some / Option setters). Default: false.

When true, silently ignore orders from OCM that are not tracked in the local cache.

pub fn maybe_ignore_external_orders( self, value: Option<bool>, ) -> BetfairExecConfigBuilder<SetIgnoreExternalOrders<S>>
where S::IgnoreExternalOrders: IsUnset,

Optional (Some / Option setters). Default: false.

When true, silently ignore orders from OCM that are not tracked in the local cache.

pub fn calculate_account_state( self, value: bool, ) -> BetfairExecConfigBuilder<SetCalculateAccountState<S>>
where S::CalculateAccountState: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to poll account state periodically.

pub fn maybe_calculate_account_state( self, value: Option<bool>, ) -> BetfairExecConfigBuilder<SetCalculateAccountState<S>>
where S::CalculateAccountState: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to poll account state periodically.

pub fn request_account_state_secs( self, value: u64, ) -> BetfairExecConfigBuilder<SetRequestAccountStateSecs<S>>
where S::RequestAccountStateSecs: IsUnset,

Optional (Some / Option setters). Default: 300.

Interval in seconds between account state polls.

pub fn maybe_request_account_state_secs( self, value: Option<u64>, ) -> BetfairExecConfigBuilder<SetRequestAccountStateSecs<S>>
where S::RequestAccountStateSecs: IsUnset,

Optional (Some / Option setters). Default: 300.

Interval in seconds between account state polls.

pub fn reconcile_market_ids_only( self, value: bool, ) -> BetfairExecConfigBuilder<SetReconcileMarketIdsOnly<S>>
where S::ReconcileMarketIdsOnly: IsUnset,

Optional (Some / Option setters). Default: false.

When true, reconciliation only requests orders matching reconcile_market_ids.

pub fn maybe_reconcile_market_ids_only( self, value: Option<bool>, ) -> BetfairExecConfigBuilder<SetReconcileMarketIdsOnly<S>>
where S::ReconcileMarketIdsOnly: IsUnset,

Optional (Some / Option setters). Default: false.

When true, reconciliation only requests orders matching reconcile_market_ids.

pub fn reconcile_market_ids( self, value: Vec<String>, ) -> BetfairExecConfigBuilder<SetReconcileMarketIds<S>>
where S::ReconcileMarketIds: IsUnset,

Optional (Some / Option setters). Market IDs to restrict reconciliation to.

pub fn maybe_reconcile_market_ids( self, value: Option<Vec<String>>, ) -> BetfairExecConfigBuilder<SetReconcileMarketIds<S>>
where S::ReconcileMarketIds: IsUnset,

Optional (Some / Option setters). Market IDs to restrict reconciliation to.

pub fn use_market_version( self, value: bool, ) -> BetfairExecConfigBuilder<SetUseMarketVersion<S>>
where S::UseMarketVersion: IsUnset,

Optional (Some / Option setters). Default: false.

When true, attach the latest market version to placeOrders and replaceOrders requests.

pub fn maybe_use_market_version( self, value: Option<bool>, ) -> BetfairExecConfigBuilder<SetUseMarketVersion<S>>
where S::UseMarketVersion: IsUnset,

Optional (Some / Option setters). Default: false.

When true, attach the latest market version to placeOrders and replaceOrders requests.